@@ -1,15 +1,21 @@
 #!perl -w
 use strict;
 use Apache::Tika::Server;
+use Getopt::Long;
+use File::Basename;
+use File::Spec;
+
+GetOptions(
+    'jar|j=s' => \my $tika_path,
+);
 
 use Data::Dumper;
 
-my $tika_glob = 'C:/Users/Corion/Projekte/Apache-Tika-Async/jar/tika-server-*.jar';
-my $tika_path = (sort { my $ad; $a =~ /-1.(\d+)/ and $ad=$1;
-                my $bd; $b =~ /-1.(\d+)/ and $bd=$1;
-                $bd <=> $ad
-              } glob $tika_glob)[0];
-die "Tika not found in '$tika_glob'" unless $tika_path and -f $tika_path; 
+if( ! $tika_path ) {
+    my $tika_glob = File::Spec->rel2abs( dirname($0) ) . '/../jar/*.jar';
+    $tika_path = Apache::Tika::Async->best_jar_file(glob $tika_glob);
+    die "Tika not found in '$tika_glob'" unless $tika_path and -f $tika_path; 
+}
 
 my $tika= Apache::Tika::Server->new(
     jarfile => $tika_path,
@@ -26,4 +32,4 @@ my $meta = $tika->get_meta($fn);
 print "Content-Type: " . $meta->{'Content-Type'} . "\n";
 
 print $tika->get_text($fn)->content;
-#print Dumper $meta;
\ No newline at end of file
+#print Dumper $meta;
